@@ -3,12 +3,14 @@ package Module::Install::DSL;
 use strict;
 use vars qw{$VERSION $ISCORE};
 BEGIN {
-	$VERSION = '0.82';
+	$VERSION = '0.83';
 	$ISCORE  = 1;
+	*inc::Module::Install::DSL::VERSION = *VERSION;
+	@inc::Module::Install::DSL::ISA     = __PACKAGE__;
 }
 
 # Load the main Module::Install as usual.
-require Module::Install;
+# require Module::Install;
 
 sub import {
 	# Read in the rest of the Makefile.PL
@@ -26,7 +28,6 @@ sub import {
 	# Load inc::Module::Install as we would in a regular Makefile.Pl
 	SCOPE: {
 		package main;
-
 		require inc::Module::Install;
 		inc::Module::Install->import;
 	}
